@@ -1,6 +1,6 @@
 /********************************************************************************
 * ReactPhysics3D physics library, http://www.reactphysics3d.com                 *
-* Copyright (c) 2010-2019 Daniel Chappuis                                       *
+* Copyright (c) 2010-2020 Daniel Chappuis                                       *
 *********************************************************************************
 *                                                                               *
 * This software is provided 'as-is', without any express or implied warranty.   *
@@ -29,7 +29,7 @@
 
 // Libraries
 #include <cassert>
-#include "Vector3.h"
+#include <reactphysics3d/mathematics/Vector3.h>
 
 /// ReactPhysics3D namespace
 namespace reactphysics3d {
